@@ -1,17 +1,17 @@
 package App::Provision::Perlbrew;
-$App::Provision::Perlbrew::VERSION = '0.0402';
-BEGIN {
-  $App::Provision::Perlbrew::AUTHORITY = 'cpan:GENE';
-}
+$App::Provision::Perlbrew::VERSION = '0.0403';
+our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 use parent qw( App::Provision::Tiny );
 
+
 sub deps
 {
     return qw( curl );
 }
 
+
 sub meet
 {
     my $self = shift;
@@ -34,7 +34,13 @@ App::Provision::Perlbrew
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
+
+=head1 FUNCTIONS
+
+=head2 deps
+
+=head2 deps
 
 =head1 AUTHOR
 
@@ -42,7 +48,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
