@@ -1,17 +1,17 @@
 package App::Provision::SourceTree;
-$App::Provision::SourceTree::VERSION = '0.0402';
-BEGIN {
-  $App::Provision::SourceTree::AUTHORITY = 'cpan:GENE';
-}
+$App::Provision::SourceTree::VERSION = '0.0403';
+our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 use parent qw( App::Provision::Tiny );
 
+
 sub deps
 {
     return qw( wget );
 }
 
+
 sub condition
 {
     my $self = shift;
@@ -28,6 +28,7 @@ sub condition
     return $condition ? 1 : 0;
 }
 
+
 sub meet
 {
     my $self = shift;
@@ -56,7 +57,15 @@ App::Provision::SourceTree
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
+
+=head1 FUNCTIONS
+
+=head2 deps
+
+=head2 condition
+
+=head2 meet
 
 =head1 AUTHOR
 
@@ -64,7 +73,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
