@@ -1,12 +1,11 @@
 package App::Provision::Ssh;
-$App::Provision::Ssh::VERSION = '0.0402';
-BEGIN {
-  $App::Provision::Ssh::AUTHORITY = 'cpan:GENE';
-}
+$App::Provision::Ssh::VERSION = '0.0403';
+our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 use parent qw( App::Provision::Tiny );
 
+
 sub condition
 {
     my $self = shift;
@@ -21,6 +20,7 @@ sub condition
     return $condition ? 1 : 0;
 }
 
+
 sub meet
 {
     my $self = shift;
@@ -58,7 +58,13 @@ App::Provision::Ssh
 
 =head1 VERSION
 
-version 0.0402
+version 0.0403
+
+=head1 FUNCTIONS
+
+=head2 condition
+
+=head2 meet
 
 =head1 AUTHOR
 
@@ -66,7 +72,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
